---
name: Documentation
about: Identify a feature which needs better explanation
title: ""
labels: documentation
assignees: ""
---

**describe the content in question**

write what feature or aspect of the code is to be addressed

**example use case**

describe a situation where one would need to access this documentation

**brief outline of updated documentation**

what form will the new documentation take? Is it a jupyter tutorial,
`help(function)` docstrings, or readthedocs information.
